'''version_warning.py

Module containing custom warning classes.

'''


class MastapyImportWarning(ImportWarning):
    '''MastapyImportWarning

    A custom warning class for mastapy import warnings.
    '''
