'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5822 import AbstractAssemblyCompoundHarmonicAnalysis
    from ._5823 import AbstractShaftCompoundHarmonicAnalysis
    from ._5824 import AbstractShaftOrHousingCompoundHarmonicAnalysis
    from ._5825 import AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis
    from ._5826 import AGMAGleasonConicalGearCompoundHarmonicAnalysis
    from ._5827 import AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis
    from ._5828 import AGMAGleasonConicalGearSetCompoundHarmonicAnalysis
    from ._5829 import AssemblyCompoundHarmonicAnalysis
    from ._5830 import BearingCompoundHarmonicAnalysis
    from ._5831 import BeltConnectionCompoundHarmonicAnalysis
    from ._5832 import BeltDriveCompoundHarmonicAnalysis
    from ._5833 import BevelDifferentialGearCompoundHarmonicAnalysis
    from ._5834 import BevelDifferentialGearMeshCompoundHarmonicAnalysis
    from ._5835 import BevelDifferentialGearSetCompoundHarmonicAnalysis
    from ._5836 import BevelDifferentialPlanetGearCompoundHarmonicAnalysis
    from ._5837 import BevelDifferentialSunGearCompoundHarmonicAnalysis
    from ._5838 import BevelGearCompoundHarmonicAnalysis
    from ._5839 import BevelGearMeshCompoundHarmonicAnalysis
    from ._5840 import BevelGearSetCompoundHarmonicAnalysis
    from ._5841 import BoltCompoundHarmonicAnalysis
    from ._5842 import BoltedJointCompoundHarmonicAnalysis
    from ._5843 import ClutchCompoundHarmonicAnalysis
    from ._5844 import ClutchConnectionCompoundHarmonicAnalysis
    from ._5845 import ClutchHalfCompoundHarmonicAnalysis
    from ._5846 import CoaxialConnectionCompoundHarmonicAnalysis
    from ._5847 import ComponentCompoundHarmonicAnalysis
    from ._5848 import ConceptCouplingCompoundHarmonicAnalysis
    from ._5849 import ConceptCouplingConnectionCompoundHarmonicAnalysis
    from ._5850 import ConceptCouplingHalfCompoundHarmonicAnalysis
    from ._5851 import ConceptGearCompoundHarmonicAnalysis
    from ._5852 import ConceptGearMeshCompoundHarmonicAnalysis
    from ._5853 import ConceptGearSetCompoundHarmonicAnalysis
    from ._5854 import ConicalGearCompoundHarmonicAnalysis
    from ._5855 import ConicalGearMeshCompoundHarmonicAnalysis
    from ._5856 import ConicalGearSetCompoundHarmonicAnalysis
    from ._5857 import ConnectionCompoundHarmonicAnalysis
    from ._5858 import ConnectorCompoundHarmonicAnalysis
    from ._5859 import CouplingCompoundHarmonicAnalysis
    from ._5860 import CouplingConnectionCompoundHarmonicAnalysis
    from ._5861 import CouplingHalfCompoundHarmonicAnalysis
    from ._5862 import CVTBeltConnectionCompoundHarmonicAnalysis
    from ._5863 import CVTCompoundHarmonicAnalysis
    from ._5864 import CVTPulleyCompoundHarmonicAnalysis
    from ._5865 import CycloidalAssemblyCompoundHarmonicAnalysis
    from ._5866 import CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis
    from ._5867 import CycloidalDiscCompoundHarmonicAnalysis
    from ._5868 import CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis
    from ._5869 import CylindricalGearCompoundHarmonicAnalysis
    from ._5870 import CylindricalGearMeshCompoundHarmonicAnalysis
    from ._5871 import CylindricalGearSetCompoundHarmonicAnalysis
    from ._5872 import CylindricalPlanetGearCompoundHarmonicAnalysis
    from ._5873 import DatumCompoundHarmonicAnalysis
    from ._5874 import ExternalCADModelCompoundHarmonicAnalysis
    from ._5875 import FaceGearCompoundHarmonicAnalysis
    from ._5876 import FaceGearMeshCompoundHarmonicAnalysis
    from ._5877 import FaceGearSetCompoundHarmonicAnalysis
    from ._5878 import FEPartCompoundHarmonicAnalysis
    from ._5879 import FlexiblePinAssemblyCompoundHarmonicAnalysis
    from ._5880 import GearCompoundHarmonicAnalysis
    from ._5881 import GearMeshCompoundHarmonicAnalysis
    from ._5882 import GearSetCompoundHarmonicAnalysis
    from ._5883 import GuideDxfModelCompoundHarmonicAnalysis
    from ._5884 import HypoidGearCompoundHarmonicAnalysis
    from ._5885 import HypoidGearMeshCompoundHarmonicAnalysis
    from ._5886 import HypoidGearSetCompoundHarmonicAnalysis
    from ._5887 import InterMountableComponentConnectionCompoundHarmonicAnalysis
    from ._5888 import KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis
    from ._5889 import KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis
    from ._5890 import KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis
    from ._5891 import KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis
    from ._5892 import KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis
    from ._5893 import KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis
    from ._5894 import KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis
    from ._5895 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis
    from ._5896 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis
    from ._5897 import MassDiscCompoundHarmonicAnalysis
    from ._5898 import MeasurementComponentCompoundHarmonicAnalysis
    from ._5899 import MountableComponentCompoundHarmonicAnalysis
    from ._5900 import OilSealCompoundHarmonicAnalysis
    from ._5901 import PartCompoundHarmonicAnalysis
    from ._5902 import PartToPartShearCouplingCompoundHarmonicAnalysis
    from ._5903 import PartToPartShearCouplingConnectionCompoundHarmonicAnalysis
    from ._5904 import PartToPartShearCouplingHalfCompoundHarmonicAnalysis
    from ._5905 import PlanetaryConnectionCompoundHarmonicAnalysis
    from ._5906 import PlanetaryGearSetCompoundHarmonicAnalysis
    from ._5907 import PlanetCarrierCompoundHarmonicAnalysis
    from ._5908 import PointLoadCompoundHarmonicAnalysis
    from ._5909 import PowerLoadCompoundHarmonicAnalysis
    from ._5910 import PulleyCompoundHarmonicAnalysis
    from ._5911 import RingPinsCompoundHarmonicAnalysis
    from ._5912 import RingPinsToDiscConnectionCompoundHarmonicAnalysis
    from ._5913 import RollingRingAssemblyCompoundHarmonicAnalysis
    from ._5914 import RollingRingCompoundHarmonicAnalysis
    from ._5915 import RollingRingConnectionCompoundHarmonicAnalysis
    from ._5916 import RootAssemblyCompoundHarmonicAnalysis
    from ._5917 import ShaftCompoundHarmonicAnalysis
    from ._5918 import ShaftHubConnectionCompoundHarmonicAnalysis
    from ._5919 import ShaftToMountableComponentConnectionCompoundHarmonicAnalysis
    from ._5920 import SpecialisedAssemblyCompoundHarmonicAnalysis
    from ._5921 import SpiralBevelGearCompoundHarmonicAnalysis
    from ._5922 import SpiralBevelGearMeshCompoundHarmonicAnalysis
    from ._5923 import SpiralBevelGearSetCompoundHarmonicAnalysis
    from ._5924 import SpringDamperCompoundHarmonicAnalysis
    from ._5925 import SpringDamperConnectionCompoundHarmonicAnalysis
    from ._5926 import SpringDamperHalfCompoundHarmonicAnalysis
    from ._5927 import StraightBevelDiffGearCompoundHarmonicAnalysis
    from ._5928 import StraightBevelDiffGearMeshCompoundHarmonicAnalysis
    from ._5929 import StraightBevelDiffGearSetCompoundHarmonicAnalysis
    from ._5930 import StraightBevelGearCompoundHarmonicAnalysis
    from ._5931 import StraightBevelGearMeshCompoundHarmonicAnalysis
    from ._5932 import StraightBevelGearSetCompoundHarmonicAnalysis
    from ._5933 import StraightBevelPlanetGearCompoundHarmonicAnalysis
    from ._5934 import StraightBevelSunGearCompoundHarmonicAnalysis
    from ._5935 import SynchroniserCompoundHarmonicAnalysis
    from ._5936 import SynchroniserHalfCompoundHarmonicAnalysis
    from ._5937 import SynchroniserPartCompoundHarmonicAnalysis
    from ._5938 import SynchroniserSleeveCompoundHarmonicAnalysis
    from ._5939 import TorqueConverterCompoundHarmonicAnalysis
    from ._5940 import TorqueConverterConnectionCompoundHarmonicAnalysis
    from ._5941 import TorqueConverterPumpCompoundHarmonicAnalysis
    from ._5942 import TorqueConverterTurbineCompoundHarmonicAnalysis
    from ._5943 import UnbalancedMassCompoundHarmonicAnalysis
    from ._5944 import VirtualComponentCompoundHarmonicAnalysis
    from ._5945 import WormGearCompoundHarmonicAnalysis
    from ._5946 import WormGearMeshCompoundHarmonicAnalysis
    from ._5947 import WormGearSetCompoundHarmonicAnalysis
    from ._5948 import ZerolBevelGearCompoundHarmonicAnalysis
    from ._5949 import ZerolBevelGearMeshCompoundHarmonicAnalysis
    from ._5950 import ZerolBevelGearSetCompoundHarmonicAnalysis
