'''types.py

A collection of additional type definitions that MASTA properties need to
support but are not explicitly a part of the Python programming language.
'''


from typing import NewType


Long = NewType('Long', int)
