'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6356 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6357 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6358 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6359 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6360 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6361 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6362 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6363 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6364 import BearingCompoundCriticalSpeedAnalysis
    from ._6365 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6366 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6367 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6368 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6369 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6370 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6371 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6372 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6373 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6374 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6375 import BoltCompoundCriticalSpeedAnalysis
    from ._6376 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6377 import ClutchCompoundCriticalSpeedAnalysis
    from ._6378 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6379 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6380 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6381 import ComponentCompoundCriticalSpeedAnalysis
    from ._6382 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6383 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6384 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6385 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6386 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6387 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6388 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6389 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6390 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6391 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6392 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6393 import CouplingCompoundCriticalSpeedAnalysis
    from ._6394 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6395 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6396 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6397 import CVTCompoundCriticalSpeedAnalysis
    from ._6398 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6399 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6400 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6401 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6402 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6403 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6404 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6405 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6406 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6407 import DatumCompoundCriticalSpeedAnalysis
    from ._6408 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6409 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6410 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6411 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6412 import FEPartCompoundCriticalSpeedAnalysis
    from ._6413 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6414 import GearCompoundCriticalSpeedAnalysis
    from ._6415 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6416 import GearSetCompoundCriticalSpeedAnalysis
    from ._6417 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6418 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6419 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6420 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6421 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6422 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6423 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6424 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6425 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6426 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6427 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6428 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6429 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6430 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6431 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6432 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6433 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6434 import OilSealCompoundCriticalSpeedAnalysis
    from ._6435 import PartCompoundCriticalSpeedAnalysis
    from ._6436 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6437 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6438 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6439 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6440 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6441 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6442 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6443 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6444 import PulleyCompoundCriticalSpeedAnalysis
    from ._6445 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6446 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6447 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6448 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6449 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6450 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6451 import ShaftCompoundCriticalSpeedAnalysis
    from ._6452 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6453 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6454 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6455 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6456 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6457 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6458 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6459 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6460 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6461 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6462 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6463 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6464 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6465 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6466 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6467 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6468 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6469 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6470 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6471 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6472 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6473 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6474 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6475 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6476 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6477 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6478 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6479 import WormGearCompoundCriticalSpeedAnalysis
    from ._6480 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6481 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6482 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6483 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6484 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis
