'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2553 import AbstractAssemblyCompoundSystemDeflection
    from ._2554 import AbstractShaftCompoundSystemDeflection
    from ._2555 import AbstractShaftOrHousingCompoundSystemDeflection
    from ._2556 import AbstractShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2557 import AGMAGleasonConicalGearCompoundSystemDeflection
    from ._2558 import AGMAGleasonConicalGearMeshCompoundSystemDeflection
    from ._2559 import AGMAGleasonConicalGearSetCompoundSystemDeflection
    from ._2560 import AssemblyCompoundSystemDeflection
    from ._2561 import BearingCompoundSystemDeflection
    from ._2562 import BeltConnectionCompoundSystemDeflection
    from ._2563 import BeltDriveCompoundSystemDeflection
    from ._2564 import BevelDifferentialGearCompoundSystemDeflection
    from ._2565 import BevelDifferentialGearMeshCompoundSystemDeflection
    from ._2566 import BevelDifferentialGearSetCompoundSystemDeflection
    from ._2567 import BevelDifferentialPlanetGearCompoundSystemDeflection
    from ._2568 import BevelDifferentialSunGearCompoundSystemDeflection
    from ._2569 import BevelGearCompoundSystemDeflection
    from ._2570 import BevelGearMeshCompoundSystemDeflection
    from ._2571 import BevelGearSetCompoundSystemDeflection
    from ._2572 import BoltCompoundSystemDeflection
    from ._2573 import BoltedJointCompoundSystemDeflection
    from ._2574 import ClutchCompoundSystemDeflection
    from ._2575 import ClutchConnectionCompoundSystemDeflection
    from ._2576 import ClutchHalfCompoundSystemDeflection
    from ._2577 import CoaxialConnectionCompoundSystemDeflection
    from ._2578 import ComponentCompoundSystemDeflection
    from ._2579 import ConceptCouplingCompoundSystemDeflection
    from ._2580 import ConceptCouplingConnectionCompoundSystemDeflection
    from ._2581 import ConceptCouplingHalfCompoundSystemDeflection
    from ._2582 import ConceptGearCompoundSystemDeflection
    from ._2583 import ConceptGearMeshCompoundSystemDeflection
    from ._2584 import ConceptGearSetCompoundSystemDeflection
    from ._2585 import ConicalGearCompoundSystemDeflection
    from ._2586 import ConicalGearMeshCompoundSystemDeflection
    from ._2587 import ConicalGearSetCompoundSystemDeflection
    from ._2588 import ConnectionCompoundSystemDeflection
    from ._2589 import ConnectorCompoundSystemDeflection
    from ._2590 import CouplingCompoundSystemDeflection
    from ._2591 import CouplingConnectionCompoundSystemDeflection
    from ._2592 import CouplingHalfCompoundSystemDeflection
    from ._2593 import CVTBeltConnectionCompoundSystemDeflection
    from ._2594 import CVTCompoundSystemDeflection
    from ._2595 import CVTPulleyCompoundSystemDeflection
    from ._2596 import CycloidalAssemblyCompoundSystemDeflection
    from ._2597 import CycloidalDiscCentralBearingConnectionCompoundSystemDeflection
    from ._2598 import CycloidalDiscCompoundSystemDeflection
    from ._2599 import CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection
    from ._2600 import CylindricalGearCompoundSystemDeflection
    from ._2601 import CylindricalGearMeshCompoundSystemDeflection
    from ._2602 import CylindricalGearSetCompoundSystemDeflection
    from ._2603 import CylindricalPlanetGearCompoundSystemDeflection
    from ._2604 import DatumCompoundSystemDeflection
    from ._2605 import DutyCycleEfficiencyResults
    from ._2606 import ExternalCADModelCompoundSystemDeflection
    from ._2607 import FaceGearCompoundSystemDeflection
    from ._2608 import FaceGearMeshCompoundSystemDeflection
    from ._2609 import FaceGearSetCompoundSystemDeflection
    from ._2610 import FEPartCompoundSystemDeflection
    from ._2611 import FlexiblePinAssemblyCompoundSystemDeflection
    from ._2612 import GearCompoundSystemDeflection
    from ._2613 import GearMeshCompoundSystemDeflection
    from ._2614 import GearSetCompoundSystemDeflection
    from ._2615 import GuideDxfModelCompoundSystemDeflection
    from ._2616 import HypoidGearCompoundSystemDeflection
    from ._2617 import HypoidGearMeshCompoundSystemDeflection
    from ._2618 import HypoidGearSetCompoundSystemDeflection
    from ._2619 import InterMountableComponentConnectionCompoundSystemDeflection
    from ._2620 import KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection
    from ._2621 import KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection
    from ._2622 import KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection
    from ._2623 import KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection
    from ._2624 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection
    from ._2625 import KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection
    from ._2626 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection
    from ._2627 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection
    from ._2628 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection
    from ._2629 import MassDiscCompoundSystemDeflection
    from ._2630 import MeasurementComponentCompoundSystemDeflection
    from ._2631 import MountableComponentCompoundSystemDeflection
    from ._2632 import OilSealCompoundSystemDeflection
    from ._2633 import PartCompoundSystemDeflection
    from ._2634 import PartToPartShearCouplingCompoundSystemDeflection
    from ._2635 import PartToPartShearCouplingConnectionCompoundSystemDeflection
    from ._2636 import PartToPartShearCouplingHalfCompoundSystemDeflection
    from ._2637 import PlanetaryConnectionCompoundSystemDeflection
    from ._2638 import PlanetaryGearSetCompoundSystemDeflection
    from ._2639 import PlanetCarrierCompoundSystemDeflection
    from ._2640 import PointLoadCompoundSystemDeflection
    from ._2641 import PowerLoadCompoundSystemDeflection
    from ._2642 import PulleyCompoundSystemDeflection
    from ._2643 import RingPinsCompoundSystemDeflection
    from ._2644 import RingPinsToDiscConnectionCompoundSystemDeflection
    from ._2645 import RollingRingAssemblyCompoundSystemDeflection
    from ._2646 import RollingRingCompoundSystemDeflection
    from ._2647 import RollingRingConnectionCompoundSystemDeflection
    from ._2648 import RootAssemblyCompoundSystemDeflection
    from ._2649 import ShaftCompoundSystemDeflection
    from ._2650 import ShaftDutyCycleSystemDeflection
    from ._2651 import ShaftHubConnectionCompoundSystemDeflection
    from ._2652 import ShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2653 import SpecialisedAssemblyCompoundSystemDeflection
    from ._2654 import SpiralBevelGearCompoundSystemDeflection
    from ._2655 import SpiralBevelGearMeshCompoundSystemDeflection
    from ._2656 import SpiralBevelGearSetCompoundSystemDeflection
    from ._2657 import SpringDamperCompoundSystemDeflection
    from ._2658 import SpringDamperConnectionCompoundSystemDeflection
    from ._2659 import SpringDamperHalfCompoundSystemDeflection
    from ._2660 import StraightBevelDiffGearCompoundSystemDeflection
    from ._2661 import StraightBevelDiffGearMeshCompoundSystemDeflection
    from ._2662 import StraightBevelDiffGearSetCompoundSystemDeflection
    from ._2663 import StraightBevelGearCompoundSystemDeflection
    from ._2664 import StraightBevelGearMeshCompoundSystemDeflection
    from ._2665 import StraightBevelGearSetCompoundSystemDeflection
    from ._2666 import StraightBevelPlanetGearCompoundSystemDeflection
    from ._2667 import StraightBevelSunGearCompoundSystemDeflection
    from ._2668 import SynchroniserCompoundSystemDeflection
    from ._2669 import SynchroniserHalfCompoundSystemDeflection
    from ._2670 import SynchroniserPartCompoundSystemDeflection
    from ._2671 import SynchroniserSleeveCompoundSystemDeflection
    from ._2672 import TorqueConverterCompoundSystemDeflection
    from ._2673 import TorqueConverterConnectionCompoundSystemDeflection
    from ._2674 import TorqueConverterPumpCompoundSystemDeflection
    from ._2675 import TorqueConverterTurbineCompoundSystemDeflection
    from ._2676 import UnbalancedMassCompoundSystemDeflection
    from ._2677 import VirtualComponentCompoundSystemDeflection
    from ._2678 import WormGearCompoundSystemDeflection
    from ._2679 import WormGearMeshCompoundSystemDeflection
    from ._2680 import WormGearSetCompoundSystemDeflection
    from ._2681 import ZerolBevelGearCompoundSystemDeflection
    from ._2682 import ZerolBevelGearMeshCompoundSystemDeflection
    from ._2683 import ZerolBevelGearSetCompoundSystemDeflection
