'''_1163.py

ElementPropertiesShellWallType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_ELEMENT_PROPERTIES_SHELL_WALL_TYPE = python_net_import('SMT.MastaAPI.FETools.VisToolsGlobal.VisToolsGlobalEnums', 'ElementPropertiesShellWallType')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementPropertiesShellWallType',)


class ElementPropertiesShellWallType(Enum):
    '''ElementPropertiesShellWallType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _ELEMENT_PROPERTIES_SHELL_WALL_TYPE

    __hash__ = None

    MONOCOQUE = 0
    LAMINATED = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ElementPropertiesShellWallType.__setattr__ = __enum_setattr
ElementPropertiesShellWallType.__delattr__ = __enum_delattr
