'''_1498.py

CellValuePosition
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_CELL_VALUE_POSITION = python_net_import('SMT.MastaAPI.Utility.ReportingPropertyFramework', 'CellValuePosition')


__docformat__ = 'restructuredtext en'
__all__ = ('CellValuePosition',)


class CellValuePosition(Enum):
    '''CellValuePosition

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _CELL_VALUE_POSITION

    __hash__ = None

    LEFT = 0
    CENTER = 1
    RIGHT = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


CellValuePosition.__setattr__ = __enum_setattr
CellValuePosition.__delattr__ = __enum_delattr
