'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1171 import CustomSplineHalfDesign
    from ._1172 import CustomSplineJointDesign
    from ._1173 import DetailedSplineJointSettings
    from ._1174 import DIN5480SplineHalfDesign
    from ._1175 import DIN5480SplineJointDesign
    from ._1176 import DudleyEffectiveLengthApproximationOption
    from ._1177 import FitTypes
    from ._1178 import GBT3478SplineHalfDesign
    from ._1179 import GBT3478SplineJointDesign
    from ._1180 import HeatTreatmentTypes
    from ._1181 import ISO4156SplineHalfDesign
    from ._1182 import ISO4156SplineJointDesign
    from ._1183 import JISB1603SplineJointDesign
    from ._1184 import ManufacturingTypes
    from ._1185 import Modules
    from ._1186 import PressureAngleTypes
    from ._1187 import RootTypes
    from ._1188 import SAEFatigueLifeFactorTypes
    from ._1189 import SAESplineHalfDesign
    from ._1190 import SAESplineJointDesign
    from ._1191 import SAETorqueCycles
    from ._1192 import SplineDesignTypes
    from ._1193 import FinishingMethods
    from ._1194 import SplineFitClassType
    from ._1195 import SplineFixtureTypes
    from ._1196 import SplineHalfDesign
    from ._1197 import SplineJointDesign
    from ._1198 import SplineMaterial
    from ._1199 import SplineRatingTypes
    from ._1200 import SplineToleranceClassTypes
    from ._1201 import StandardSplineHalfDesign
    from ._1202 import StandardSplineJointDesign
