'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._936 import AddendumModificationDistributionRule
    from ._937 import BacklashSpecification
    from ._938 import BasicRackProfiles
    from ._939 import CaseHardeningProperties
    from ._940 import CreateNewSuitableCutterOption
    from ._941 import CrossedAxisCylindricalGearPair
    from ._942 import CrossedAxisCylindricalGearPairLineContact
    from ._943 import CrossedAxisCylindricalGearPairPointContact
    from ._944 import CylindricalGearAbstractRack
    from ._945 import CylindricalGearAbstractRackFlank
    from ._946 import CylindricalGearBasicRack
    from ._947 import CylindricalGearBasicRackFlank
    from ._948 import CylindricalGearCuttingOptions
    from ._949 import CylindricalGearDefaults
    from ._950 import CylindricalGearDesign
    from ._951 import CylindricalGearDesignConstraint
    from ._952 import CylindricalGearDesignConstraints
    from ._953 import CylindricalGearDesignConstraintsDatabase
    from ._954 import CylindricalGearDesignConstraintSettings
    from ._955 import CylindricalGearDesignSettings
    from ._956 import CylindricalGearFlankDesign
    from ._957 import CylindricalGearMeshDesign
    from ._958 import CylindricalGearMeshFlankDesign
    from ._959 import CylindricalGearMicroGeometrySettings
    from ._960 import CylindricalGearPinionTypeCutter
    from ._961 import CylindricalGearPinionTypeCutterFlank
    from ._962 import CylindricalGearProfileMeasurement
    from ._963 import CylindricalGearProfileMeasurementType
    from ._964 import CylindricalGearProfileModifications
    from ._965 import CylindricalGearSetDesign
    from ._966 import CylindricalGearSetFlankDesign
    from ._967 import CylindricalGearSetMacroGeometryOptimiser
    from ._968 import CylindricalGearSetManufacturingConfigurationSelection
    from ._969 import CylindricalGearTableMGItemDetail
    from ._970 import CylindricalGearTableWithMGCharts
    from ._971 import CylindricalGearToothThicknessSpecification
    from ._972 import CylindricalMeshAngularBacklash
    from ._973 import CylindricalMeshedGear
    from ._974 import CylindricalMeshedGearFlank
    from ._975 import CylindricalMeshLinearBacklashSpecification
    from ._976 import CylindricalPlanetaryGearSetDesign
    from ._977 import CylindricalPlanetGearDesign
    from ._978 import DIN3967AllowanceSeries
    from ._979 import DIN3967ToleranceSeries
    from ._980 import DoubleAxisScaleAndRange
    from ._981 import FinishStockSpecification
    from ._982 import FinishToothThicknessDesignSpecification
    from ._983 import GearFitSystems
    from ._984 import GearManufacturingConfigSetupViewModel
    from ._985 import GearSetFCAImportSetup
    from ._986 import GearSetManufacturingConfigurationSetup
    from ._987 import GeometrySpecificationType
    from ._988 import HardenedMaterialProperties
    from ._989 import HardnessProfileCalculationMethod
    from ._990 import HeatTreatmentType
    from ._991 import ISO6336Geometry
    from ._992 import ISO6336GeometryBase
    from ._993 import ISO6336GeometryForShapedGears
    from ._994 import ISO6336GeometryManufactured
    from ._995 import LinearBacklashSepcification
    from ._996 import LTCALoadCaseModifiableSettings
    from ._997 import LtcaSettings
    from ._998 import MicroGeometryConvention
    from ._999 import MicroGeometryProfileConvention
    from ._1000 import Micropitting
    from ._1001 import NamedPlanetAssemblyIndex
    from ._1002 import NamedPlanetSideBandAmplitudeFactor
    from ._1003 import ReadonlyToothThicknessSpecification
    from ._1004 import RelativeMeasurementViewModel
    from ._1005 import RelativeValuesSpecification
    from ._1006 import Scuffing
    from ._1007 import ScuffingCoefficientOfFrictionMethods
    from ._1008 import ScuffingTemperatureMethodsAGMA
    from ._1009 import ScuffingTemperatureMethodsISO
    from ._1010 import ShaperEdgeTypes
    from ._1011 import SpurGearLoadSharingCodes
    from ._1012 import StandardRack
    from ._1013 import StandardRackFlank
    from ._1014 import SurfaceRoughness
    from ._1015 import ThicknessType
    from ._1016 import TiffAnalysisSettings
    from ._1017 import TipAlterationCoefficientMethod
    from ._1018 import TolerancedMetalMeasurements
    from ._1019 import TolerancedValueSpecification
    from ._1020 import ToothFlankFractureAnalysisSettings
    from ._1021 import ToothThicknessSpecification
    from ._1022 import ToothThicknessSpecificationBase
    from ._1023 import TypeOfMechanismHousing
    from ._1024 import Usage
