'''_2183.py

ShaftDiameterModificationDueToRollingBearingRing
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_SHAFT_DIAMETER_MODIFICATION_DUE_TO_ROLLING_BEARING_RING = python_net_import('SMT.MastaAPI.SystemModel.PartModel', 'ShaftDiameterModificationDueToRollingBearingRing')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftDiameterModificationDueToRollingBearingRing',)


class ShaftDiameterModificationDueToRollingBearingRing(Enum):
    '''ShaftDiameterModificationDueToRollingBearingRing

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _SHAFT_DIAMETER_MODIFICATION_DUE_TO_ROLLING_BEARING_RING

    __hash__ = None

    PRESERVE_RING_MASS = 0
    USE_RACE_DIAMETER = 1
    IGNORE_BEARING_RING = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ShaftDiameterModificationDueToRollingBearingRing.__setattr__ = __enum_setattr
ShaftDiameterModificationDueToRollingBearingRing.__delattr__ = __enum_delattr
