'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3865 import AbstractAssemblyCompoundPowerFlow
    from ._3866 import AbstractShaftCompoundPowerFlow
    from ._3867 import AbstractShaftOrHousingCompoundPowerFlow
    from ._3868 import AbstractShaftToMountableComponentConnectionCompoundPowerFlow
    from ._3869 import AGMAGleasonConicalGearCompoundPowerFlow
    from ._3870 import AGMAGleasonConicalGearMeshCompoundPowerFlow
    from ._3871 import AGMAGleasonConicalGearSetCompoundPowerFlow
    from ._3872 import AssemblyCompoundPowerFlow
    from ._3873 import BearingCompoundPowerFlow
    from ._3874 import BeltConnectionCompoundPowerFlow
    from ._3875 import BeltDriveCompoundPowerFlow
    from ._3876 import BevelDifferentialGearCompoundPowerFlow
    from ._3877 import BevelDifferentialGearMeshCompoundPowerFlow
    from ._3878 import BevelDifferentialGearSetCompoundPowerFlow
    from ._3879 import BevelDifferentialPlanetGearCompoundPowerFlow
    from ._3880 import BevelDifferentialSunGearCompoundPowerFlow
    from ._3881 import BevelGearCompoundPowerFlow
    from ._3882 import BevelGearMeshCompoundPowerFlow
    from ._3883 import BevelGearSetCompoundPowerFlow
    from ._3884 import BoltCompoundPowerFlow
    from ._3885 import BoltedJointCompoundPowerFlow
    from ._3886 import ClutchCompoundPowerFlow
    from ._3887 import ClutchConnectionCompoundPowerFlow
    from ._3888 import ClutchHalfCompoundPowerFlow
    from ._3889 import CoaxialConnectionCompoundPowerFlow
    from ._3890 import ComponentCompoundPowerFlow
    from ._3891 import ConceptCouplingCompoundPowerFlow
    from ._3892 import ConceptCouplingConnectionCompoundPowerFlow
    from ._3893 import ConceptCouplingHalfCompoundPowerFlow
    from ._3894 import ConceptGearCompoundPowerFlow
    from ._3895 import ConceptGearMeshCompoundPowerFlow
    from ._3896 import ConceptGearSetCompoundPowerFlow
    from ._3897 import ConicalGearCompoundPowerFlow
    from ._3898 import ConicalGearMeshCompoundPowerFlow
    from ._3899 import ConicalGearSetCompoundPowerFlow
    from ._3900 import ConnectionCompoundPowerFlow
    from ._3901 import ConnectorCompoundPowerFlow
    from ._3902 import CouplingCompoundPowerFlow
    from ._3903 import CouplingConnectionCompoundPowerFlow
    from ._3904 import CouplingHalfCompoundPowerFlow
    from ._3905 import CVTBeltConnectionCompoundPowerFlow
    from ._3906 import CVTCompoundPowerFlow
    from ._3907 import CVTPulleyCompoundPowerFlow
    from ._3908 import CycloidalAssemblyCompoundPowerFlow
    from ._3909 import CycloidalDiscCentralBearingConnectionCompoundPowerFlow
    from ._3910 import CycloidalDiscCompoundPowerFlow
    from ._3911 import CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow
    from ._3912 import CylindricalGearCompoundPowerFlow
    from ._3913 import CylindricalGearMeshCompoundPowerFlow
    from ._3914 import CylindricalGearSetCompoundPowerFlow
    from ._3915 import CylindricalPlanetGearCompoundPowerFlow
    from ._3916 import DatumCompoundPowerFlow
    from ._3917 import ExternalCADModelCompoundPowerFlow
    from ._3918 import FaceGearCompoundPowerFlow
    from ._3919 import FaceGearMeshCompoundPowerFlow
    from ._3920 import FaceGearSetCompoundPowerFlow
    from ._3921 import FEPartCompoundPowerFlow
    from ._3922 import FlexiblePinAssemblyCompoundPowerFlow
    from ._3923 import GearCompoundPowerFlow
    from ._3924 import GearMeshCompoundPowerFlow
    from ._3925 import GearSetCompoundPowerFlow
    from ._3926 import GuideDxfModelCompoundPowerFlow
    from ._3927 import HypoidGearCompoundPowerFlow
    from ._3928 import HypoidGearMeshCompoundPowerFlow
    from ._3929 import HypoidGearSetCompoundPowerFlow
    from ._3930 import InterMountableComponentConnectionCompoundPowerFlow
    from ._3931 import KlingelnbergCycloPalloidConicalGearCompoundPowerFlow
    from ._3932 import KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow
    from ._3933 import KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow
    from ._3934 import KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow
    from ._3935 import KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow
    from ._3936 import KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow
    from ._3937 import KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow
    from ._3938 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow
    from ._3939 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow
    from ._3940 import MassDiscCompoundPowerFlow
    from ._3941 import MeasurementComponentCompoundPowerFlow
    from ._3942 import MountableComponentCompoundPowerFlow
    from ._3943 import OilSealCompoundPowerFlow
    from ._3944 import PartCompoundPowerFlow
    from ._3945 import PartToPartShearCouplingCompoundPowerFlow
    from ._3946 import PartToPartShearCouplingConnectionCompoundPowerFlow
    from ._3947 import PartToPartShearCouplingHalfCompoundPowerFlow
    from ._3948 import PlanetaryConnectionCompoundPowerFlow
    from ._3949 import PlanetaryGearSetCompoundPowerFlow
    from ._3950 import PlanetCarrierCompoundPowerFlow
    from ._3951 import PointLoadCompoundPowerFlow
    from ._3952 import PowerLoadCompoundPowerFlow
    from ._3953 import PulleyCompoundPowerFlow
    from ._3954 import RingPinsCompoundPowerFlow
    from ._3955 import RingPinsToDiscConnectionCompoundPowerFlow
    from ._3956 import RollingRingAssemblyCompoundPowerFlow
    from ._3957 import RollingRingCompoundPowerFlow
    from ._3958 import RollingRingConnectionCompoundPowerFlow
    from ._3959 import RootAssemblyCompoundPowerFlow
    from ._3960 import ShaftCompoundPowerFlow
    from ._3961 import ShaftHubConnectionCompoundPowerFlow
    from ._3962 import ShaftToMountableComponentConnectionCompoundPowerFlow
    from ._3963 import SpecialisedAssemblyCompoundPowerFlow
    from ._3964 import SpiralBevelGearCompoundPowerFlow
    from ._3965 import SpiralBevelGearMeshCompoundPowerFlow
    from ._3966 import SpiralBevelGearSetCompoundPowerFlow
    from ._3967 import SpringDamperCompoundPowerFlow
    from ._3968 import SpringDamperConnectionCompoundPowerFlow
    from ._3969 import SpringDamperHalfCompoundPowerFlow
    from ._3970 import StraightBevelDiffGearCompoundPowerFlow
    from ._3971 import StraightBevelDiffGearMeshCompoundPowerFlow
    from ._3972 import StraightBevelDiffGearSetCompoundPowerFlow
    from ._3973 import StraightBevelGearCompoundPowerFlow
    from ._3974 import StraightBevelGearMeshCompoundPowerFlow
    from ._3975 import StraightBevelGearSetCompoundPowerFlow
    from ._3976 import StraightBevelPlanetGearCompoundPowerFlow
    from ._3977 import StraightBevelSunGearCompoundPowerFlow
    from ._3978 import SynchroniserCompoundPowerFlow
    from ._3979 import SynchroniserHalfCompoundPowerFlow
    from ._3980 import SynchroniserPartCompoundPowerFlow
    from ._3981 import SynchroniserSleeveCompoundPowerFlow
    from ._3982 import TorqueConverterCompoundPowerFlow
    from ._3983 import TorqueConverterConnectionCompoundPowerFlow
    from ._3984 import TorqueConverterPumpCompoundPowerFlow
    from ._3985 import TorqueConverterTurbineCompoundPowerFlow
    from ._3986 import UnbalancedMassCompoundPowerFlow
    from ._3987 import VirtualComponentCompoundPowerFlow
    from ._3988 import WormGearCompoundPowerFlow
    from ._3989 import WormGearMeshCompoundPowerFlow
    from ._3990 import WormGearSetCompoundPowerFlow
    from ._3991 import ZerolBevelGearCompoundPowerFlow
    from ._3992 import ZerolBevelGearMeshCompoundPowerFlow
    from ._3993 import ZerolBevelGearSetCompoundPowerFlow
