'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1974 import AbstractShaftToMountableComponentConnection
    from ._1975 import BearingInnerSocket
    from ._1976 import BearingOuterSocket
    from ._1977 import BeltConnection
    from ._1978 import CoaxialConnection
    from ._1979 import ComponentConnection
    from ._1980 import ComponentMeasurer
    from ._1981 import Connection
    from ._1982 import CVTBeltConnection
    from ._1983 import CVTPulleySocket
    from ._1984 import CylindricalComponentConnection
    from ._1985 import CylindricalSocket
    from ._1986 import DatumMeasurement
    from ._1987 import ElectricMachineStatorSocket
    from ._1988 import InnerShaftSocket
    from ._1989 import InnerShaftSocketBase
    from ._1990 import InterMountableComponentConnection
    from ._1991 import MountableComponentInnerSocket
    from ._1992 import MountableComponentOuterSocket
    from ._1993 import MountableComponentSocket
    from ._1994 import OuterShaftSocket
    from ._1995 import OuterShaftSocketBase
    from ._1996 import PlanetaryConnection
    from ._1997 import PlanetarySocket
    from ._1998 import PlanetarySocketBase
    from ._1999 import PulleySocket
    from ._2000 import RealignmentResult
    from ._2001 import RollingRingConnection
    from ._2002 import RollingRingSocket
    from ._2003 import ShaftSocket
    from ._2004 import ShaftToMountableComponentConnection
    from ._2005 import Socket
    from ._2006 import SocketConnectionOptions
    from ._2007 import SocketConnectionSelection
