'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2273 import GearMaterialExpertSystemMaterialDetails
    from ._2274 import GearMaterialExpertSystemMaterialOptions
